import sys

import os


class HideOutput(object):
    """
    A context manager that block stdout for its scope, usage:

    with HideOutput():
        os.system('ls -l')
    """

    # One important thing to note is that a process gets three different file descriptors from the OS when launched:
    # stdin: 0
    # stdout: 1
    # stderr: 2

    def __init__(self, *args, **kw):
        sys.stdout.flush()
        self._origstdout = sys.stdout

        # Duplicate stdout to a different file descriptor number
        self._oldstdout_fno = os.dup(sys.stdout.fileno())

        # /dev/null is used just to discard what is being printed
        self._devnull = os.open(os.devnull, os.O_WRONLY)

    def __enter__(self):
        # Duplicate stdout (file descriptor 1) to a different file descriptor number
        self._newstdout = os.dup(1)

        # Duplicate the file descriptor for /dev/null and overwrite the value for stdout (file descriptor 1)
        os.dup2(self._devnull, 1)

        # Close devnull after duplication (no longer needed)
        os.close(self._devnull)

        # Use the original stdout to still be able to print to stdout within python
        sys.stdout = os.fdopen(self._newstdout, 'w')

    def __exit__(self, exc_type, exc_val, exc_tb):
        sys.stdout = self._origstdout
        sys.stdout.flush()

        # Duplicate the file descriptor for old stdout and overwrite the value for stdout (file descriptor 1)
        os.dup2(self._oldstdout_fno, 1)



import os
from distutils.core import setup

setup(
    name='cytopast',
    packages=['cytopast'],
    package_data={'cytopast': [os.path.join('templates', '*.html'), os.path.join('templates', '*.js'),
                               os.path.join('..', 'README.md')]},
    long_description=open('README.md').read(),
    include_package_data=True,
    platform=['Linux', 'Windows', 'Mac OS'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    version='0.3.5',
    description='Visualisation of PASTML trees.',
    author='Anna Zhukova',
    author_email='anna.zhukova@pasteur.fr',
    url='https://gitlab.pasteur.fr/phylo/cytopast',
    download_url='https://gitlab.pasteur.fr/phylo/cytopast/archive/0.1.zip',
    keywords=['PASTML', 'visualisation', 'phylogeny'],
    install_requires=['ete3', 'pandas', 'numpy', 'jinja2', 'pastml'],
    requires=['ete3', 'pandas', 'numpy', 'jinja2', 'pastml']
)
